Package: martini
Type: Package
Title: GWAS Incorporating Networks
Version: 1.32.0
Authors@R: c(person("Hector", "Climente-Gonzalez", 
                    email = "hector.climente@a.riken.jp",
                    role = c("aut", "cre"),
                    comment = c(ORCID = "0000-0002-3030-7471")),
             person("Chloe-Agathe", "Azencott", 
                    role = "aut",
                    comment = c(ORCID = "0000-0003-1003-301X")))
Description: martini deals with the low power inherent to GWAS studies by using 
    prior knowledge represented as a network. SNPs are the vertices of the 
    network, and the edges represent biological relationships between them 
    (genomic adjacency, belonging to the same gene, physical interaction between
    protein products). The network is scanned using SConES, which looks for 
    groups of SNPs maximally associated with the phenotype, that form a close 
    subnetwork.
License: GPL-3
LazyData: TRUE
Imports: igraph (>= 1.0.1), Matrix, memoise (>= 2.0.0), methods (>=
        3.3.2), Rcpp (>= 0.12.8), snpStats (>= 1.20.0), stats, utils,
Suggests: biomaRt (>= 2.34.1), circlize (>= 0.4.11), STRINGdb (>=
        2.2.0), httr (>= 1.2.1), IRanges (>= 2.8.2), S4Vectors (>=
        0.12.2), knitr, testthat, readr, rmarkdown
Depends: R (>= 4.0)
LinkingTo: Rcpp, RcppEigen (>= 0.3.3.5.0)
RoxygenNote: 7.2.3
Encoding: UTF-8
biocViews: Software, GenomeWideAssociation, SNP, GeneticVariability,
        Genetics, FeatureExtraction, GraphAndNetwork, Network
VignetteBuilder: knitr
URL: https://github.com/hclimente/martini
BugReports: https://github.com/hclimente/martini/issues
git_url: https://git.bioconductor.org/packages/martini
git_branch: RELEASE_3_23
git_last_commit: 428b2d4
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-28 23:01:16 UTC; biocbuild
Author: Hector Climente-Gonzalez [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3030-7471>),
  Chloe-Agathe Azencott [aut] (ORCID:
    <https://orcid.org/0000-0003-1003-301X>)
Maintainer: Hector Climente-Gonzalez <hector.climente@a.riken.jp>
