% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/db.R
\name{get_gxg}
\alias{get_gxg}
\title{Get gene interactions}
\usage{
get_gxg(db, organism, flush)
}
\arguments{
\item{db}{String containing the database to obtain the gene-gene interactions
from. Possible values: 'biogrid', 'string'.}

\item{organism}{Tax ID of the studied organism. The default is 9606 (human).}

\item{flush}{Remove cached results? Boolean value.}
}
\value{
A data.frame with two columns with pairs of interacting proteins.
}
\description{
Wrapper for the different functions to get gene-gene 
interactions. Supports cached results.
}
\keyword{internal}
